<?php
require_once( STRIPE_BASE_DIR . '/app/controller/controller.php' );
require_once( STRIPE_BASE_DIR . '/app/view/admin.view.php' );
require_once( STRIPE_BASE_DIR . '/app/model/admin.model.php' );
/*****************************************************************************
 * Class AdminController                                                     *
 *****************************************************************************/
class AdminController extends Controller
{
  private $remote_response;
  private $response_info;
  private $upgrade_server;
  private $admin_email;
  /***************************************************************************
   * __construct()                                                           *
   * *************************************************************************/
  public function __contruct()
  {
    $this->addMixin( new DebugModel() );
  }
 /****************************************************************************
   * menu_setup()                                                            *
   * *************************************************************************/
  public function menu_setup() 
  {
    DebugModel::debug('menu_setup()');
    add_options_page('Stripe Settings', // $page_title
                     'Stripe Settings', // $menu_title
                     'manage_options', // $capability
                     'stripe-settings', // $menu_slug
                     array( $this, 'render_options_page' ) // $function
                   );
    add_action('admin_print_scripts-settings_page_stripe-settings', 
      array( $this, 'add_javascript'));
  }
 /***************************************************************************
   * upgrade()                                                               *
   *                                                                         *
   * controller to listen for a form to be submitted with POST['action']     *
   * set to "upgrade". This function with then tell the model to do          *
   * the right thing with this information.                                  *
   * *************************************************************************/
  public function upgrade()
  {
    $this->debug("upgrade()");
    if (isset( $_POST['action'])
        && ($_POST['action'] == 'upgrade')
        && (wp_verify_nonce($_POST['stripe_nonce'], 'stripe-nonce'))
    ){
      $this->upgrade_server = ( ADMIN_TEST ? 
          "http://atomicbroadcast.net/upgrade.php" :
          "https://loveoaklandgroup.com/upgrade.php");
      $this->debug("upgrade_server: $this->upgrade_server");

      $this->copy_post_vars();

      $this->post_payment_to_remote( $this );
 
      if ($this->response_info['http_code'] == 201){
        // upgrade charged successfully so upgrade and redirect
        $this->debug("remote responded OK.");
        $this->debug($this->remote_response);

        $this->set_option( 'payment', 'paid' );
        $redirect = add_query_arg(array(
          'payment' => 'paid'
        ), $_POST['redirect']);
        wp_redirect($redirect);
        exit;
      }else{
        $this->debug("remote did not return OK when trying to upgrade.");
        $this->debug($this->remote_response);
        $this->debug($this->response_info);
        throw new Exception( 'remote did not return OK when trying to upgrade.' );
      }
    }
  }
  /***************************************************************************
   * copy_post_vars()                                                        *
   * *************************************************************************/
  private function copy_post_vars()
  {
    $this->admin_email = get_bloginfo( 'admin_email' );
    $this->set_amount( $_POST['amount'] );
    $this->set_product_id( $_POST['product_id'] );
    $this->set_description( $_POST['description'] );
    $this->set_stripeToken( $_POST['stripeToken'] );
  }
  /***************************************************************************
   * setters                                                                 *
   * *************************************************************************/
  public function set_remote_response( $remote_response )
  {
    $this->remote_response = $remote_response;
  }
  public function set_response_info( $response_info )
  {
    $this->response_info = $response_info;
  }
  /***************************************************************************
   * getters                                                                 *
   * *************************************************************************/
  public function get_upgrade_server()
  {
    return $this->upgrade_server;
  }
  public function get_admin_email()
  {
    return $this->admin_email;
  }
}

if (!defined( 'ADMIN_TEST' )) {
  define( 'ADMIN_TEST', false);
}
?>
