<?php
class PressPayView{
  /*
   * stripe_button_form(amount, image, desc, product_id, description)
   *
   * Show the stripe button wrapped in a form 
   */
  public function stripe_button_form( $controller )
  {
    $controller->debug( 'stripe_button_form( $controller )' );
    $controller->debug( 'publishable_key: ' . $controller->publishable_key );
    ob_start(); ?>
    <form method="POST" id="stripe-button-form">
      <script
        src="https://checkout.stripe.com/v2/checkout.js" class="stripe-button"
        data-key="<?php echo $controller->publishable_key; ?>"
        data-name="<?php echo esc_attr( $controller->get_headline() ); ?>"
        data-amount="<?php echo esc_attr( $controller->get_amount() ); ?>"
        data-description="<?php echo esc_attr( $controller->get_description() ); ?>"
        data-image="<?php echo $controller->get_image(); ?>"
        data-address=""
      ></script>
      <input type="hidden" name="action" value="stripe"/>
      <input type="hidden" name="redirect"
             value="<?php echo(get_permalink()); ?>"/>
      <input type="hidden" name="amount"
             value="<?php echo( base64_encode( $controller->get_amount() ) ); ?>"/>
      <input type="hidden" name="product_id"
             value="<?php echo( $controller->get_product_id() ); ?>"/>
      <input type="hidden" name="description"
             value="<?php echo( $controller->get_description() ); ?>"/>
      <input type="hidden" name="stripe_nonce"
             value="<?php echo wp_create_nonce('stripe-nonce'); ?>"/>
    </form>
    <?php echo ob_get_clean();
  }

  /*
   * confirm_payment_get_email()
   *
   * Display a form in a dialog to let the user know their payment was processed
   * and to get them to enter their email (or update their email).
   */
  public function confirm_payment_get_email($email){
    //show form to enter email
    ob_start();?>
    <div class="dialog app" title="<h1>Payment Recieved</h1><h2>We're almost done.</h2>" style="visibility: none">
    <div class="panel">
      <form name="stripe-confirmation-form" id="stripe-confirmation-form" method="POST" action="#">
        <article>
          <div class="email">
            <label for="email">Email:</label>
            <input type="email" value="" placeholder="<?php echo($email); ?>" 
              name="email" id="confirmation_email">
          </div>
          <div class="message">
            Please enter your email so that we can send you a receipt.
          </div>
        </article>
        <div class="address us">
          <article>
            <label class="hidden-address" id="shipping-line-1" for="line_1">Shipping Address</label>
            <fieldset class="hidden-address">
              <div class "line_1">
                <input name="shipping_line_1" id="shipping_line_1" type="text" placeholder="Street" 
		      autocompletetype="address-line1">
              </div>
              <div class="hbox">
                <div class="city">
                  <input name="shipping_city" id="shipping_city" type="text" placeholder="City" 
		      autocompletetype="city">
                </div>
                <div class="city">
                  <input name="shipping_state" id="shipping_state" type="text" placeholder="State" 
		      autocompletetype="state">
                </div>
<!--
          <div class="state us">
            <div class="select changed" data-placeholder="State">
              <span>CA</span>
              <select name="state" placeholder="State" autocomplete="state" required>
                <option value>State:</option>
                <option value="CA">CA</option>
              </select>
            </div>
          </div>
-->
              </div>
              <div class="hbox">
                <div class="zip us">
                  <input name="shipping_zip" id="shipping_zip" type="text" placeholder="Zip" 
		      autocompletetype="postal-code">
                </div>
                <div class="city">
                  <input name="shipping_country" id="shipping_country" type="text" placeholder="Country"
		      autocompletetype="country">
                </div>
<!--
          <div class="country">
            <div class="select changed" data-placeholder="Country">
              <span>United States</span>
              <select name="country" placeholder="Country" x-autocomplete="country" required>
                <option value="US">United States</option>
              </select>
            </div>
          </div>
-->
              </div>
            </fieldset>
          <div class="hbox">
            <input class="checkbox" id="shipping-address" type="checkbox" 
              name="shipping-address" value="different">
            <div class="message checkbox">
              Shipping Address differs from Billing Address.
            </div>
          </div>
          </article>
        </div>
        <footer>
          <button class="blue submit" id="stripe-confirmation-submit">
            <span>Submit Email</span>
          </button>
        </footer>
      </form>
      </div>
    </div>
    <?php echo ob_get_clean();
  } 

  public function mobile_confirmation(){
    ob_start(); ?>
    <!DOCTYPE html> 
    <html>

    <head>
	    <meta charset="utf-8">
	    <meta name="viewport" content="width=device-width, initial-scale=1"> 
	    <title>Single page template</title> 
	    <link rel="stylesheet" href="http://code.jquery.com/mobile/1.3.0-rc.1/jquery.mobile-1.3.0-rc.1.min.css" />
	    <script src="http://code.jquery.com/jquery-1.9.0.min.js"></script>
	    <script src="http://code.jquery.com/mobile/1.3.0-rc.1/jquery.mobile-1.3.0-rc.1.min.js"></script>
	    <script type="text/javascript">
		    jQuery(document).ready(function($){
		      $('#mobile-confirmation-form').submit(function(e){
		        mobileConfirmationHandler(e);
		      });
		      $('#mobile-confirmation-submit').click(function(e){
		        mobileConfirmationHandler(e);
		      });
		    });

		    function mobileConfirmationHandler(e){
		      e.submit();
		    }
	    </script>
    </head> 
    <body>
      <div data-role="page">
        <div data-roll="header">
          <h1>Thank You</h1><h2>Your order is on it's way</h2>
        </div><!-- /header -->
        <div data-role="content">
	    <form name="mobile-confirmation-form" id="mobile-confirmation-form"
	          method="POST" action="#"
	          data-ajax="false">
	      <label for="email" class="ui-hidden-accessible">Email:</label>
	      <input type="email" value="" placeholder="Email"
		           name="email" id="email"/>
	      <input type="hidden" name="payment" value="paid"/>
	    </form>
        </div>
        <button class="blue submit" id="mobile-confirmation-submit">
          <span>Submit Email</span>
        </button>
      </div>
    </body>
    </html>
    <?php echo ob_get_clean();
  }

  public function thank_you(){
    ob_start(); ?>
    <div class="dialog app" 
         title="<h1>Thank You</h1><h2>Your order is on it's way</h2>">
      <div class="panel">
        <article>
          Thanks for Shopping with Us.
        </article>
        <footer>
          <button class="blue submit close">
            <span>Close</span>
          </button>
        </footer>
      </div>
    </div>
    <?php echo ob_get_clean();
  }

}
?>
